##### Manifests

You might want to upload files to your project, such as PDFs, Word documents, or other files. You can upload them in the administration interface and link to them in your project pages.

##### Files

You might want to upload files to your project, such as PDFs, Word documents, or other files. You can upload them in the administration interface and link to them in your project pages.